---
name: Bug Report
about: Create a report to help Syntrend improve
title: "bug: "
labels: "bug"
assignees: ""
---

# Bug Report

**Syntrend Version:** vx.x.x

## Current behavior

<!-- Describe how the bug manifests. -->

## Expected behavior

<!-- Describe what the behavior would be without the bug. -->

## Steps to reproduce

<!--  Please explain the steps required to duplicate the issue, especially if you are able to provide a sample application. -->
- <!-- Step 1: do this thing... -->

## Related Project File

<!-- If you are able to illustrate the bug or feature request with an example, please provide it here. -->

```
insert short code snippets here
```

## Other information

<!-- List any other information that is relevant to your issue. Related issues, suggestions on how to fix, Stack Overflow links, forum links, etc. -->